# JournalEntryStatus

Status of Journal Entry.

## Enum

* `CREATED` (value: `'Created'`)

* `CANCELLED` (value: `'Cancelled'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


